@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -83,6 +83,12 @@ sub generate {
             ($flavor =~ /7/ && $x eq $tones[6])
             ||
             ($flavor =~ /[#b]9/ && $x eq $tones[1])
+            ||
+            ($flavor =~ /dim/ && $x eq $tones[2])
+            ||
+            ($flavor =~ /dim/ && $x eq $tones[6])
+            ||
+            ($flavor =~ /aug/ && $x eq $tones[6])
         ) {
             print "DROP: $x\n" if $self->verbose;
             next;
@@ -126,7 +132,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -143,6 +149,11 @@ version 0.0101
 
 C<MIDI::Bassline::Walk> generates randomized, walking basslines.
 
+The logic (and music theory) implemented here, definitely generates
+some sour notes.  And sometimes too much!  This is an approximate
+composition tool, and not a drop-in bass player.  Import the rendered
+MIDI into a DAW and alter things until they are suitable.
+
 =head1 ATTRIBUTES
 
 =head2 intervals
@@ -186,7 +197,7 @@ Create a new C<MIDI::Bassline::Walk> object.
   $notes = $bassline->generate;
   $notes = $bassline->generate($chord, $n);
 
-Generate B<n> MIDI pitch numbers given the given B<chord>.
+Generate B<n> MIDI pitch numbers given the B<chord>.
 
 Defaults:
 
